using System.Reflection;
using System.Runtime.CompilerServices;

[assembly: AssemblyVersion("0.1.4")]
[assembly: AssemblyTitle("themonospot-gui")]
[assembly: AssemblyDescription("Gtk-Sharp Gui for themonospot solution")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("Armando Basile")]
[assembly: AssemblyProduct("themonospot-gui")]
[assembly: AssemblyCopyright("Armando Basile")]
[assembly: AssemblyTrademark("None")]
[assembly: AssemblyDelaySign(false)]
[assembly: AssemblyKeyFile("")]


